==> qtjambi-multimedia-debuginfo-linux-x64-5.15.18.jar: sources/QtJambiMultimedia/QVideoDeviceSelectorControl_shell.h <==
#ifndef QVIDEODEVICESELECTORCONTROL_SHELL_H
#define QVIDEODEVICESELECTORCONTROL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qvideodeviceselectorcontrol.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QVideoDeviceSelectorControl_shell : public QVideoDeviceSelectorControl, public QtJambiShellInterface
{
public:
    QVideoDeviceSelectorControl_shell(QObject* parent0 = nullptr);
    ~QVideoDeviceSelectorControl_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    int defaultDevice() const override;
    int deviceCount() const override;
    QString deviceDescription(int index0) const override;
    QString deviceName(int index0) const override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    int selectedDevice() const override;
    void setSelectedDevice(int index0) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QVideoDeviceSelectorControl_access : public QVideoDeviceSelectorControl
{
    jint __qt_defaultDevice(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_deviceCount(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_deviceDescription_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint index0) const;
    jstring __qt_deviceName_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint index0) const;
    jint __qt_selectedDevice(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setSelectedDevice_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint index0);
};

#endif // QVIDEODEVICESELECTORCONTROL_SHELL_H

==> qtjambi-multimedia-debuginfo-linux-x64-5.15.20.jar: sources/QtJambiMultimedia/QVideoDeviceSelectorControl_shell.h <==
#ifndef QVIDEODEVICESELECTORCONTROL_SHELL_H
#define QVIDEODEVICESELECTORCONTROL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qvideodeviceselectorcontrol.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QVideoDeviceSelectorControl_shell : public QVideoDeviceSelectorControl, public QtJambiShellInterface
{
public:
    QVideoDeviceSelectorControl_shell(QObject* parent0 = nullptr);
    ~QVideoDeviceSelectorControl_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    int defaultDevice() const override;
    int deviceCount() const override;
    QString deviceDescription(int index0) const override;
    QString deviceName(int index0) const override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    int selectedDevice() const override;
    void setSelectedDevice(int index0) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QVideoDeviceSelectorControl_access : public QVideoDeviceSelectorControl
{
    jint __qt_defaultDevice_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_deviceCount_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_deviceDescription_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint index0) const;
    jstring __qt_deviceName_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint index0) const;
    jint __qt_selectedDevice_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setSelectedDevice_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint index0);
};

#endif // QVIDEODEVICESELECTORCONTROL_SHELL_H
